==> huaweicloudsdkcodeartsbuild-3.1.90-py2.py3-none-any.whl: huaweicloudsdkcodeartsbuild/v3/model/delete_build_job_response_body_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteBuildJobResponseBodyResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_id': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'job_id': 'job_id',
        'project_id': 'project_id'
    }

    def __init__(self, job_id=None, project_id=None):
        """DeleteBuildJobResponseBodyResult

        The model defined in huaweicloud sdk

        :param job_id: 构建任务ID
        :type job_id: str
        :param project_id: 构建任务所在项目的ID
        :type project_id: str
        """
        
        

        self._job_id = None
        self._project_id = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if project_id is not None:
            self.project_id = project_id

    @property
    def job_id(self):
        """Gets the job_id of this DeleteBuildJobResponseBodyResult.

        构建任务ID

        :return: The job_id of this DeleteBuildJobResponseBodyResult.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this DeleteBuildJobResponseBodyResult.

        构建任务ID

        :param job_id: The job_id of this DeleteBuildJobResponseBodyResult.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def project_id(self):
        """Gets the project_id of this DeleteBuildJobResponseBodyResult.

        构建任务所在项目的ID

        :return: The project_id of this DeleteBuildJobResponseBodyResult.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DeleteBuildJobResponseBodyResult.

        构建任务所在项目的ID

        :param project_id: The project_id of this DeleteBuildJobResponseBodyResult.
        :type project_id: str
        """
        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteBuildJobResponseBodyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsbuild-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcodeartsbuild/v3/model/delete_build_job_response_body_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteBuildJobResponseBodyResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_id': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'job_id': 'job_id',
        'project_id': 'project_id'
    }

    def __init__(self, job_id=None, project_id=None):
        r"""DeleteBuildJobResponseBodyResult

        The model defined in huaweicloud sdk

        :param job_id: 构建任务ID
        :type job_id: str
        :param project_id: 构建任务所在项目的ID
        :type project_id: str
        """
        
        

        self._job_id = None
        self._project_id = None
        self.discriminator = None

        if job_id is not None:
            self.job_id = job_id
        if project_id is not None:
            self.project_id = project_id

    @property
    def job_id(self):
        r"""Gets the job_id of this DeleteBuildJobResponseBodyResult.

        构建任务ID

        :return: The job_id of this DeleteBuildJobResponseBodyResult.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        r"""Sets the job_id of this DeleteBuildJobResponseBodyResult.

        构建任务ID

        :param job_id: The job_id of this DeleteBuildJobResponseBodyResult.
        :type job_id: str
        """
        self._job_id = job_id

    @property
    def project_id(self):
        r"""Gets the project_id of this DeleteBuildJobResponseBodyResult.

        构建任务所在项目的ID

        :return: The project_id of this DeleteBuildJobResponseBodyResult.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        r"""Sets the project_id of this DeleteBuildJobResponseBodyResult.

        构建任务所在项目的ID

        :param project_id: The project_id of this DeleteBuildJobResponseBodyResult.
        :type project_id: str
        """
        self._project_id = project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteBuildJobResponseBodyResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
